==> zio-aws-ec2_2.12-5.17.152.1-sources.jar: zio/aws/ec2/model/Phase2IntegrityAlgorithmsListValue.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class Phase2IntegrityAlgorithmsListValue(
    value: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.Phase2IntegrityAlgorithmsListValue = {
    import Phase2IntegrityAlgorithmsListValue.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.Phase2IntegrityAlgorithmsListValue
      .builder()
      .optionallyWith(value.map(value => value: java.lang.String))(_.value)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.Phase2IntegrityAlgorithmsListValue.ReadOnly =
    zio.aws.ec2.model.Phase2IntegrityAlgorithmsListValue.wrap(buildAwsValue())
}
object Phase2IntegrityAlgorithmsListValue {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.Phase2IntegrityAlgorithmsListValue
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.Phase2IntegrityAlgorithmsListValue =
      zio.aws.ec2.model
        .Phase2IntegrityAlgorithmsListValue(value.map(value => value))
    def value: Option[String]
    def getValue: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("value", value)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.Phase2IntegrityAlgorithmsListValue
  ) extends zio.aws.ec2.model.Phase2IntegrityAlgorithmsListValue.ReadOnly {
    override val value: Option[String] =
      scala.Option(impl.value()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.Phase2IntegrityAlgorithmsListValue
  ): zio.aws.ec2.model.Phase2IntegrityAlgorithmsListValue.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.12-5.19.7.1-sources.jar: zio/aws/ec2/model/Phase2IntegrityAlgorithmsListValue.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class Phase2IntegrityAlgorithmsListValue(
    value: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.Phase2IntegrityAlgorithmsListValue = {
    import Phase2IntegrityAlgorithmsListValue.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.Phase2IntegrityAlgorithmsListValue
      .builder()
      .optionallyWith(value.map(value => value: java.lang.String))(_.value)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.Phase2IntegrityAlgorithmsListValue.ReadOnly =
    zio.aws.ec2.model.Phase2IntegrityAlgorithmsListValue.wrap(buildAwsValue())
}
object Phase2IntegrityAlgorithmsListValue {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.Phase2IntegrityAlgorithmsListValue
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.Phase2IntegrityAlgorithmsListValue =
      zio.aws.ec2.model
        .Phase2IntegrityAlgorithmsListValue(value.map(value => value))
    def value: Optional[String]
    def getValue: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("value", value)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.Phase2IntegrityAlgorithmsListValue
  ) extends zio.aws.ec2.model.Phase2IntegrityAlgorithmsListValue.ReadOnly {
    override val value: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.value())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.Phase2IntegrityAlgorithmsListValue
  ): zio.aws.ec2.model.Phase2IntegrityAlgorithmsListValue.ReadOnly =
    new Wrapper(impl)
}
